Skip to main content Crate takoyaki_core Copy item path Source Cache Cache struct is used to retrive and write to caches CacheConfig Config Paths All the paths are stored and constructed here globally Pick Defines which keys should be picked for specific value Printable Defines a printable PrintableGrid The PrintableGrid. This handles generating the grid and printing it to the terminal Request The request type State Handles where the data should be retrieved from cache or from request
In case of fetching, it populates the cache with the new data Takoyaki The main entry point of the plugin. Takoyaki assembles all the parts of your plugin
This function just contains 1 function, that needs to be called at the runtime, and the rest will be handled internally Unicode TakoyakiError Defines all the errors returned by takoyaki SDK convert_to_headermap Converts a HashMap<&str, &str> to a reqwest::HeaderMap